==> haskell-config-ini-0.2.2.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.2.0
id: config-ini-0.2.2.0-4DHa0PRsHn18RxBy3Tkznl
key: config-ini-0.2.2.0-4DHa0PRsHn18RxBy3Tkznl
license: BSD3
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
author: Getty Ritter <config-ini@infinitenegativeutility.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
abi: c6d16075d71512ea1e7954fa1e1ebe95
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/config-ini-0.2.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/config-ini-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/config-ini-0.2.2.0
hs-libraries: HSconfig-ini-0.2.2.0-4DHa0PRsHn18RxBy3Tkznl
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm
    transformers-0.5.2.0 megaparsec-6.4.0-JBoMVyKn1kwBunw5T8mgbx
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm=a19fc431946ec4b21dbc4dc9d0f6448c
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             megaparsec-6.4.0-JBoMVyKn1kwBunw5T8mgbx=ee332569d51b94de10e6c0503f04d4f3
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.2.0-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.2.0
id: config-ini-0.2.2.0-DIZm5Q3uMEZECb8EuYVxvP
key: config-ini-0.2.2.0-DIZm5Q3uMEZECb8EuYVxvP
license: BSD3
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
author: Getty Ritter <config-ini@infinitenegativeutility.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
abi: c8cd3faee84f70729553c85339ad657b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/config-ini-0.2.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/config-ini-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/config-ini-0.2.2.0
hs-libraries: HSconfig-ini-0.2.2.0-DIZm5Q3uMEZECb8EuYVxvP
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
    transformers-0.5.2.0 megaparsec-6.4.0-BwCWj8ySQbTHd5NLmOqaLx
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             megaparsec-6.4.0-BwCWj8ySQbTHd5NLmOqaLx=c4c690edf67727c97fa5c4dc22faaa32
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
